@@ -14,9 +14,9 @@ use Bencher::Backend;
 use List::Util qw(first);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-02-08'; # DATE
+our $DATE = '2022-11-29'; # DATE
 our $DIST = 'Bencher-Backend'; # DIST
-our $VERSION = '1.061'; # VERSION
+our $VERSION = '1.062'; # VERSION
 
 sub munge_result {
     my ($self, $envres) = @_;
@@ -64,7 +64,7 @@ Bencher::Formatter::CodeStartup - Munge code_startup results
 
 =head1 VERSION
 
-This document describes version 1.061 of Bencher::Formatter::CodeStartup (from Perl distribution Bencher-Backend), released on 2022-02-08.
+This document describes version 1.062 of Bencher::Formatter::CodeStartup (from Perl distribution Bencher-Backend), released on 2022-11-29.
 
 =head1 DESCRIPTION
 
@@ -105,9 +105,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
