@@ -14,9 +14,9 @@ use Role::Tiny::With;
 with 'Bencher::Role::ResultMunger';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-02-08'; # DATE
+our $DATE = '2022-11-29'; # DATE
 our $DIST = 'Bencher-Backend'; # DIST
-our $VERSION = '1.061'; # VERSION
+our $VERSION = '1.062'; # VERSION
 
 sub munge_result {
     my ($self, $envres) = @_;
@@ -80,7 +80,7 @@ Bencher::Formatter::ScaleTime - Scale time to make it convenient
 
 =head1 VERSION
 
-This document describes version 1.061 of Bencher::Formatter::ScaleTime (from Perl distribution Bencher-Backend), released on 2022-02-08.
+This document describes version 1.062 of Bencher::Formatter::ScaleTime (from Perl distribution Bencher-Backend), released on 2022-11-29.
 
 =for Pod::Coverage .*
 
@@ -109,9 +109,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
